StringJoiner class

Constructors

StringJoiner(String? join)

Properties

hashCode → int
The hash code for this object.
no setterinherited
join → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
str ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator +(dynamic value) → StringJoiner
operator ==(Object other) → bool
The equality operator.
inherited