UpdateRequest<T> class

Implemented types

Constructors

UpdateRequest(Producer<T> producer, int requestId, Logger log, {String? debugLabel})

Properties

debugLabel ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
log → Logger
final
operation ↔ CancelableOperation<UpdateResult<T>>?
getter/setter pair
producer → Producer<T>
final
props → List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
requestId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

cancel() → Future
compareTo(UpdateRequest other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → CancelableOperation<UpdateResult<T>>?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited