FuturesStream class

Constructors

FuturesStream(List<FutureOr> futures)

Properties

futures → List<FutureOr>
final
hashCode → int
The hash code for this object.
no setterinherited
result → List
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → Stream<List>
no setter

Methods

close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited