ValueStream<T> class abstract

Interface representing a stream that has a current or initial value as well.

See HStream, which provides the initial value at the start of the stream, and SyncStream, which keeps the value up-to-date

Implementers
Available extensions

Constructors

ValueStream.empty()
factory
ValueStream.of(FutureOr<T?> first, [Stream<T>? after, String? debugName])
factory

Properties

after → Stream<T>
no setter
debugName → String?
no setter
future → Future<T?>
no setter
hashCode → int
The hash code for this object.
no setterinherited
isFirstResolved → bool
no setter
isNotEmpty → bool

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

no setter
keys → ValueStream<Iterable<K>>

Available on ValueStream<Map<K, V>>, provided by the ValueStreamOfMapExtensions extension

no setter
length → int

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → ValueStream<Iterable<V>>

Available on ValueStream<Map<K, V>>, provided by the ValueStreamOfMapExtensions extension

no setter

Methods

awaitEach() → ValueStream<Future<Iterable<X>>>

Available on ValueStream<Iterable<Future<X>>>, provided by the ValueStreamIterableFutureExtensions extension

combined<R, O>(ValueStream<O> other, R combiner(T? self, O? other)) → ValueStream<R>

Available on ValueStream<T>, provided by the ValueStreamExtensions extension

Combines another stream.
combinedUnresolved<R, O>(ValueStream<O> other, Resolvable<R?> combiner(FutureOr<T?> self, FutureOr<O?> other)) → ValueStream<R?>

Available on ValueStream<T>, provided by the ValueStreamExtensions extension

Combines another stream, passing unresolved Futures
combineWith(Iterable<ValueStream<Iterable<X>>> others, [String? debugName]) → ValueStream<Iterable<X>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

debounced([Duration? duration]) → ValueStream<T>

Available on ValueStream<T>, provided by the ValueStreamExtensions extension

expandEach<R>(Iterable<R> expander(X input)) → ValueStream<Iterable<R>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

filteredBy<R>(ValueStream<R> other, bool filter(X item, R? other)) → ValueStream<Iterable<X>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

Filters this stream using a result of another stream. This allows us to apply the filter when either the filtering source changes or the original list changes.
filterEntries(bool predicate(K key, V value)) → ValueStream<Map<K, V>>

Available on ValueStream<Map<K, V>>, provided by the ValueStreamOfMapExtensions extension

filterItems(bool predicate(X input)?) → ValueStream<Iterable<X>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

flatten([T? initialValue, bool filterNotNull = true]) → Stream<T?>

Available on ValueStream<T>, provided by the ValueStreamExtensions extension

followedBy(ValueStream<Iterable<X>> other) → ValueStream<Iterable<X>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

get() → FutureOr<T?>
listen(void onData(T item)) → StreamSubscription

Available on ValueStream<T>, provided by the ValueStreamExtensions extension

map<R>(R mapper(T input)) → ValueStream<R>
Basics of converting something over
mapEach<R>(R mapper(X input)) → ValueStream<Iterable<R>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

mapEntries<R>(MapEntry<K, R> mapper(K key, V value)) → ValueStream<Map<K, R>>

Available on ValueStream<Map<K, V>>, provided by the ValueStreamOfMapExtensions extension

mapValues<R>(R mapper(K key, V value)) → ValueStream<Map<K, R>>

Available on ValueStream<Map<K, V>>, provided by the ValueStreamOfMapExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek(void peek(T item)) → ValueStream<T>

Available on ValueStream<T>, provided by the ValueStreamExtensions extension

resolve([T? ifAbsent]) → T?
sampled() → ValueStream<X?>

Available on ValueStream<Future<X>>, provided by the ValueStreamFutureExtensions extension

thenMap<R>(R mapper(X input)) → ValueStream<Future<R>>

Available on ValueStream<Future<X>>, provided by the ValueStreamFutureExtensions extension

thenMapEach<R>(R mapper(X input)) → ValueStream<Iterable<Future<R>>>

Available on ValueStream<Iterable<Future<X>>>, provided by the ValueStreamIterableFutureExtensions extension

toMap() → ValueStream<Map<K, V>>

Available on ValueStream<Iterable<MapEntry<K, V>>>, provided by the ValueStreamIterableMapEntryExtensions extension

toString() → String
A string representation of this object.
inherited
toSyncStream([void onChange(T value)?, String? name]) → SyncStream<T>

Available on ValueStream<T>, provided by the ValueStreamExtensions extension

where(Predicate<T?> predicate) → ValueStream<T>

Available on ValueStream<T>, provided by the ValueStreamExtensions extension

Filters the entire stream, including the current element
whereNotNull() → ValueStream<T>

Available on ValueStream<T>, provided by the ValueStreamExtensions extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

controller<X>(String debugLabel, {X? initialValue, bool isUnique = true}) → ValueStreamController<X>
singleValue<X>({String? debugLabel, FutureOr<X>? initialValue}) → ValueStream<X>