ValueStreamController<T> class

A class that tracks a single value as a stream, but can also provide the latest value;

Constructors

ValueStreamController(String debugLabel, {T? initialValue, bool isUnique = true})

Properties

currentValue ↔ T?
getter/setter pair
debugLabel → String
final
hashCode → int
The hash code for this object.
no setterinherited
isUnique → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → ValueStream<T?>
no setter

Methods

add(T? newValue) → void
close() → Future
dispose() → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited