ValueStreamIterableExtensions<X> extension

on

Properties

isNotEmpty → bool

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

no setter
length → int

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

no setter

Methods

combineWith(Iterable<ValueStream<Iterable<X>>> others, [String? debugName]) → ValueStream<Iterable<X>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

expandEach<R>(Iterable<R> expander(X input)) → ValueStream<Iterable<R>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

filteredBy<R>(ValueStream<R> other, bool filter(X item, R? other)) → ValueStream<Iterable<X>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

Filters this stream using a result of another stream. This allows us to apply the filter when either the filtering source changes or the original list changes.
filterItems(bool predicate(X input)?) → ValueStream<Iterable<X>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

followedBy(ValueStream<Iterable<X>> other) → ValueStream<Iterable<X>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension

mapEach<R>(R mapper(X input)) → ValueStream<Iterable<R>>

Available on ValueStream<Iterable<X>>, provided by the ValueStreamIterableExtensions extension